

set -ex



pip check
jupyter labextension list
jupyter server extension list
jupyter serverextension list
jupyter server extension list 1>server_extensions 2>&1
cat server_extensions | grep -ie "jupyter_server_proxy.*OK"
jupyter serverextension list 1>serverextensions 2>&1
cat serverextensions | grep -ie "jupyter_server_proxy.*OK"
jupyter labextension list 1>labextensions 2>&1
cat labextensions | grep -ie "@jupyterlab/server-proxy.*3\.2\.2.*OK"
exit 0
